@@ -1,5 +1,40 @@
 #if 0
 
+N_("Neapolitan Pizza")
+N_("Original pizza dough from Naples with tomato sauce on pizza stone.")
+N_("Toppings are not included in the recipe.")
+N_("The sauce can easily produced in bigger amounts and deep-freezed in freezer bags.")
+N_("Dough: Dissolve the yeast in lukewarm water. Mix the flour, semolina and salt.")
+N_("If brewer's yeast is not available, one can also use fresh yeast.")
+N_("[timer:00:10:00]Put the yeast-water mixture to the flour and let it swell for 10 minutes.")
+N_("[timer:00:15:00]Knead the dough with a kneading machine for at least 15 minutes. This is important so that the dough gets highly elastic.")
+N_("[timer:08:00:00]Put the yeast dough covered for at least 8 hours (better 24 hours) in the refrigerator.")
+N_("Sauce: Peel the shallots and the garlic and chop them finely.")
+N_("Heat olive oil in a small pot and fry garlic and shallots shortly. Don't let them get brown.")
+N_("[timer:00:30:00]Add the sieved tomatoes, tomato paste, red wine, oregano, salt and pepper. Let it boil slightly for 30 minutes so it gets that thick it does not run down the pizza.")
+N_("[timer:01:30:00]Dough: Put the dough on a floured work surface. Create balls as big as fists (each 180-200g). Cover them with a moist kitchen towel and let them rise for an other 90 minutes at room temperature.")
+N_("When you are ready to start, put the pizza stone in the oven and heat it up to [temperature:300C] (maximum temperature).")
+N_("Take a dough ball and form with your hands into a round flat thin piece. Don't use a rolling pin, otherwise you destroy the yeast cultures.")
+N_("Strew semolina on the shovel, so it can later easier slide of the shovel and put the dough piece on it.")
+N_("Put the pizza sauce with a spoon on it, then pizza cheese (if you don't use e.g. mozzarella) and then the other toppings of your choice.")
+N_("The pizza cheese should be below the toppings. This way the good ingredients are better presented.")
+N_("If you use wet toppings like pineapples or mozzarella, dry them in a sieve before.")
+N_("Don't put too much on the pizza.")
+N_("Put the pizza with the shovel in the oven and bake it till it is brown. Duration is depending on oven temperature.")
+N_("Quinoa Salad")
+N_("Yummy salad that goes with just about anything.")
+N_("Cook it like rice so bring quinoa and water to a boil  Reduce heat to medium-low, cover, and simmer until quinoa is tender and water has been absorbed, 10 to 15 minutes. Set aside to cool, this is important otherwise things get sticky ")
+N_("Whisk olive oil, lime juice, cumin, 1 teaspoon salt, and red pepper flakes together in a bowl.")
+N_("Combine everything but the cilantro, into a big bowl and toss to coat. Next season with salt & pepper and stir in the cilantro. Server right away or chill it for later.")
+N_("If needed you can add some zesty Italian dressing for if it gets a little dry the next day.")
+N_("Lemon Cake")
+N_("My favorite Lemon Cake recipe. The cake is light and juicy.")
+N_("Preheat the oven to [temperature:175C] - [temperature:195C].")
+N_("First abrade the shell of the lemons. Squeeze the juice out of two (per serve) lemons.")
+N_("Stir eggs and sugar foamy. Sieve the flour and add it with the vanilla sugar, baking powder, lemon shells and margarine one by one. Stir everything well.")
+N_("[timer:00:20:00]Put the dough on a baking tray with baking paper and put it in the preheated oven. Bake it for 20min (middle rail).")
+N_("Now mix the lemon juice little by little with the sieved powered sugar. Be sparing with the juice, the sugar icing must be pretty viscous.")
+N_("Apply the sugar icing on the cake with a fork as long the cake is warm. Let the cake cool down.")
 N_("Henry's Goulash")
 N_("Originally from Hungary, this dish is widespread in Central Europe.")
 N_("This is my friend Henry's version of it.")
