@@ -605,18 +605,9 @@ open_filechooser (GrImageViewer *viewer)
 
         window = gtk_widget_get_ancestor (GTK_WIDGET (viewer), GTK_TYPE_APPLICATION_WINDOW);
 
-        if (in_flatpak_sandbox () && !portals_available ()) {
-                GtkWidget *dialog;
-
-                dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                                 GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                 GTK_MESSAGE_ERROR,
-                                                 GTK_BUTTONS_OK,
-                                                 _("Missing the desktop portals needed to open files from inside a flatpak sandbox. Please install xdg-desktop-portal and xdg-desktop-portal-gtk on your system."));
-                g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-                gtk_widget_show (dialog);
+        if (in_flatpak_sandbox () &&
+            !portal_available (GTK_WINDOW (window), "org.freedesktop.portal.FileChooser"))
                 return;
-        }
 
         chooser = gtk_file_chooser_native_new (_("Select an Image"),
                                                GTK_WINDOW (window),
